@@ -11,6 +11,7 @@ CommentDefinition::CommentDefinition() :
     isAfterWhiteSpaces(false)
 {
     qDebug() << "CommentDefinition constructor called";
+    qDebug() << "CommentDefinition::CommentDefinition() exit";
 }
 
 
@@ -22,19 +23,29 @@ void CommentDefinition::setComments(QString singleLineComment, QString multiLine
     singleLine = singleLineComment;
     multiLineStart = multiLineCommentStart;
     multiLineEnd = multiLineCommentEnd;
+    qDebug() << "CommentDefinition::setComments() exit";
 }
 bool CommentDefinition::isValid() const
 {
-    return hasSingleLineStyle() || hasMultiLineStyle();
+    qDebug() << "CommentDefinition::isValid() entry";
+    bool result = hasSingleLineStyle() || hasMultiLineStyle();
+    qDebug() << "CommentDefinition::isValid() exit, result:" << result;
+    return result;
 }
 
 bool CommentDefinition::hasSingleLineStyle() const
 {
-    return !singleLine.isEmpty();
+    qDebug() << "CommentDefinition::hasSingleLineStyle() entry";
+    bool result = !singleLine.isEmpty();
+    qDebug() << "CommentDefinition::hasSingleLineStyle() exit, result:" << result;
+    return result;
 }
 
 bool CommentDefinition::hasMultiLineStyle() const
 {
-    return !multiLineStart.isEmpty() && !multiLineEnd.isEmpty();
+    qDebug() << "CommentDefinition::hasMultiLineStyle() entry";
+    bool result = !multiLineStart.isEmpty() && !multiLineEnd.isEmpty();
+    qDebug() << "CommentDefinition::hasMultiLineStyle() exit, result:" << result;
+    return result;
 }
 
